@@ -55,6 +55,7 @@ COMPLEX_TYPES = {
         'JobSearchBasic',
         'LocationSearchBasic',
         'TransactionSearchBasic',
+        'InboundShipmentSearchBasic',
         'VendorSearchBasic',
         'SubsidiarySearchBasic',
         'EmployeeSearchBasic',
@@ -102,6 +103,7 @@ COMPLEX_TYPES = {
         'DepartmentSearch',
         'ItemSearch', 'ItemSearchAdvanced', 'ItemSearchRow',
         'ClassificationSearch',
+        'PriceLevelSearch'
     ],
 
     'ns19': [
@@ -132,6 +134,7 @@ COMPLEX_TYPES = {
         'VendorPaymentApplyList',
         'VendorPaymentCredit',
         'VendorPaymentCreditList',
+        'InboundShipmentSearch',
         'VendorPaymentApply'
     ],
 
